@@ -81,6 +81,15 @@ QString AboutData::contributors() const {
 
   list << tr("<a href=\"mailto:ayman@aymansmail.co.cc\">Ayman Siddiqui</a>: The default theme.");
   list << tr("<a href=\"mailto:khaledhosny@eglug.org\">Khaled Hosny</a>: Great help with the font.");
+  list << tr("<a href=\"mailto:cloud596@hotmail.com\">Alfiansyah Rahman</a>: Creating the great logo.");
 
   return list.join("<br />");
 }
+
+QString AboutData::platform() const {
+#ifdef Q_WS_MAEMO_5
+  return "Maemo5";
+#else
+  return "Harmattan";
+#endif
+}
