@@ -81,6 +81,8 @@ void Recitations::refresh() {
 
   QStringList entries(m_dir.entryList(QDir::AllDirs | QDir::NoDotAndDotDot));
 
+  entries += m_dir.entryList(QStringList() << "*.zip", QDir::Files | QDir::NoDotAndDotDot);
+
   int x = 0;
 
   foreach (const QString& entry, entries) {
@@ -90,6 +92,7 @@ void Recitations::refresh() {
     }
   }
 
+
   emit installedChanged();
 }
 
@@ -179,6 +182,10 @@ bool Recitations::isPlaying() const {
 
 void Recitations::playerStateChanged() {
   emit playingChanged();
+
+  if (m_player->state() != QMediaPlayer::PlayingState) {
+    stop();
+  }
 }
 
 void Recitations::playerError() {
